pub struct ObserveOptions {
pub use_image: Option<bool>,
pub full_page: Option<bool>,
pub wait_ms: Option<u64>,
pub include_content: Option<bool>,
}Fields
use_image: Option<bool>full_page: Option<bool>wait_ms: Option<u64>include_content: Option<bool>Trait Implementations
Sourceimpl Clone for ObserveOptions
impl Clone for ObserveOptions
Sourcefn clone(&self) -> ObserveOptions
fn clone(&self) -> ObserveOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObserveOptions
impl Debug for ObserveOptions
Sourceimpl Default for ObserveOptions
impl Default for ObserveOptions
Sourcefn default() -> ObserveOptions
fn default() -> ObserveOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ObserveOptions
impl<'de> Deserialize<'de> for ObserveOptions
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ObserveOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ObserveOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ObserveOptions
impl JsonSchema for ObserveOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ObserveOptions
impl Serialize for ObserveOptions
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more