pub struct SessionDetail {
pub session_id: String,
pub session_type: SessionType,
pub worker_id: Option<String>,
pub user_email: Option<String>,
pub last_activity: Option<i64>,
pub idle_secs: Option<i64>,
pub connected: Option<bool>,
}Fields
session_id: Stringsession_type: SessionTypeworker_id: Option<String>user_email: Option<String>last_activity: Option<i64>idle_secs: Option<i64>connected: Option<bool>Trait Implementations
Sourceimpl Clone for SessionDetail
impl Clone for SessionDetail
Sourcefn clone(&self) -> SessionDetail
fn clone(&self) -> SessionDetail
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionDetail
impl Debug for SessionDetail
Sourceimpl<'de> Deserialize<'de> for SessionDetail
impl<'de> Deserialize<'de> for SessionDetail
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SessionDetail, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SessionDetail, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionDetail
impl JsonSchema for SessionDetail
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SessionDetail
impl Serialize for SessionDetail
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more