pub struct ShellCreateSessionRequest {
pub image: Option<String>,
pub language: Option<String>,
pub timeout_secs: Option<u32>,
pub working_dir: Option<String>,
}Fields
image: Option<String>language: Option<String>timeout_secs: Option<u32>working_dir: Option<String>Trait Implementations
Sourceimpl Clone for ShellCreateSessionRequest
impl Clone for ShellCreateSessionRequest
Sourcefn clone(&self) -> ShellCreateSessionRequest
fn clone(&self) -> ShellCreateSessionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellCreateSessionRequest
impl Debug for ShellCreateSessionRequest
Sourceimpl Default for ShellCreateSessionRequest
impl Default for ShellCreateSessionRequest
Sourcefn default() -> ShellCreateSessionRequest
fn default() -> ShellCreateSessionRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ShellCreateSessionRequest
impl<'de> Deserialize<'de> for ShellCreateSessionRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellCreateSessionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellCreateSessionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellCreateSessionRequest
impl JsonSchema for ShellCreateSessionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ShellCreateSessionRequest
impl Serialize for ShellCreateSessionRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more