pub struct ShellCreateSessionResponse {
pub session_id: String,
pub status: String,
pub worker_id: Option<String>,
pub language: Option<String>,
}Fields
session_id: Stringstatus: Stringworker_id: Option<String>language: Option<String>Trait Implementations
Sourceimpl Clone for ShellCreateSessionResponse
impl Clone for ShellCreateSessionResponse
Sourcefn clone(&self) -> ShellCreateSessionResponse
fn clone(&self) -> ShellCreateSessionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellCreateSessionResponse
impl Debug for ShellCreateSessionResponse
Sourceimpl<'de> Deserialize<'de> for ShellCreateSessionResponse
impl<'de> Deserialize<'de> for ShellCreateSessionResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellCreateSessionResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellCreateSessionResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellCreateSessionResponse
impl JsonSchema for ShellCreateSessionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ShellCreateSessionResponse
impl Serialize for ShellCreateSessionResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more