pub struct ShellListItem {
pub shell_id: String,
pub status: String,
pub image: String,
pub created_at: String,
pub last_activity: String,
}Fields
shell_id: Stringstatus: Stringimage: Stringcreated_at: Stringlast_activity: StringTrait Implementations
Sourceimpl Clone for ShellListItem
impl Clone for ShellListItem
Sourcefn clone(&self) -> ShellListItem
fn clone(&self) -> ShellListItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellListItem
impl Debug for ShellListItem
Sourceimpl<'de> Deserialize<'de> for ShellListItem
impl<'de> Deserialize<'de> for ShellListItem
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellListItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ShellListItem, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellListItem
impl JsonSchema for ShellListItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ShellListItem
impl Serialize for ShellListItem
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more